# Hub Pip Plugin

Black Duck Hub setup tool/pip plugin.  Generates a dependency list inside the Hub for your Python projects. 

## Build

[![Build Status](https://travis-ci.org/blackducksoftware/hub-pip.svg?branch=master)](https://travis-ci.org/blackducksoftware/hub-pip)
[![Black Duck Security Risk](https://copilot.blackducksoftware.com/github/groups/blackducksoftware/locations/hub-pip/public/results/branches/master/badge-risk.svg)](https://copilot.blackducksoftware.com/github/groups/blackducksoftware/locations/hub-pip/public/results/branches/master)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

## Where can I get the latest release? ##
You can download the latest release from PyPi: https://pypi.python.org/pypi/hub-pip

## Documentation

Latest documentation can be found on our public [Black Duck Confluence](https://blackducksoftware.atlassian.net/wiki/display/INTDOCS/)
